@@ -31,7 +31,30 @@ class AliasedGroup(click.Group):
 
 @click.group(cls=AliasedGroup)
 def cli():
-    """DS framework cli"""
+    """
+    DS framework cli
+
+    ** how to use **
+
+    g = generate
+
+    create project
+
+    ds-framework-cli g project my-new-project
+
+    ds-framework-cli generate project my-new-project
+
+    cd my-new-project
+
+    create forcer
+
+    ds-framework-cli g forcer my-new-forcer
+
+    create predictable
+
+    ds-framework-cli g predictable my-new-predictable
+
+    """
 # @click.option("--type", prompt="type", help="type of component")
 # @click.option("--project_name", prompt="project_name", help="project_name")
 # def apis(type, project_name):
